@@ -13,10 +13,10 @@ setMethod(
                     s,
                     composite = factor(y@composite)
                 ),
-                mapping = aes(
-                    x = s1,
-                    y = s2,
-                    shape = composite
+                mapping = aes_string(
+                    x = "s1",
+                    y = "s2",
+                    shape = "composite"
                 ),
                 colour = alpha("black", 0.4)
             ) +
