@@ -14,7 +14,7 @@ setMethod(
         ggplot() +
             geom_point(
                 data = as.data.frame(s),
-                mapping = aes(x = s1, y = s2),
+                mapping = aes_string(x = "s1", y = "s2"),
                 colour = alpha("black", 0.4)
             ) +
             coord_equal() +
